<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>新</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>從不</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>每 %1 個回合</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation type="unfinished">改變武器設置</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>無法使用此彈藥設置</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation type="unfinished">修改遊戲設置</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>無法錄入檔 %1</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>開啟服務端出現錯誤</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="obsolete">新</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>請選擇一個記錄</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>zh_TW.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>DEMO %1 打不開</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>地圖</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>過濾</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小型</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中型</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大型</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>洞穴</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>曲折</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>主題</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>埠</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>錯誤沒找到這個主機。請檢查主機名稱和埠設置。</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>連接被拒絕</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>房間損壞</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>退出原因：</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>被踢出</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">您的匿稱%1
在Hedgewars.org已註冊
請輸入您的密碼
或選擇另一個匿稱：</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1***%2已經進入房間</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1***%2已經進入</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1***%2已經離開(%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1***%2已經離開</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf 返回錯誤-渲染文字失敗，可能有關freetype2的bug。建議升級 freetype。</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">伺服器資訊：</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">設定信息</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>清空帳戶緩存</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>連接中...</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">清除</translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished">讀取</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>常規</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>進階</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;最佳射手是&lt;b&gt;%1&lt;/b&gt;。傷害 &lt;b&gt;%2&lt;/b&gt;點。&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;最佳殺手是&lt;b&gt;%1&lt;/b&gt;单回合擊殺刺蝟數&lt;b&gt;%2&lt;/b&gt;&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;本輪總共有&lt;b&gt;%1&lt;/b&gt;只刺蝟被擊殺&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>本地遊戲（在一台電腦上）</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>網路遊戲（通過網路）</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>請選擇一個伺服器</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>房間管理</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>局域網遊戲</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>官方伺服器</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>新隊伍</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>修改隊伍設定</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>重命名對話方塊</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>輸入新的檔案名:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>不能改變名字</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>不能刪除檔</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>請從清單選擇記錄</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>建立</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>加入</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>管理員功能</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation type="unfinished">房間名：</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation type="unfinished">遊戲正在等待中。
您可以加入等待遊戲開始。</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation type="unfinished">遊戲正在進行中。
您可以加入觀戰但必須等遊戲結束才能參與遊戲。</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation type="unfinished">%1是房主，他可以調整設置、開始遊戲。</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation type="unfinished">隨機地圖</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>遊戲可以在預先創建或者隨機產生的地圖上進行。</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation type="unfinished">遊戲設置包括一般選項例如回合時間，突然死亡或吸血模式。</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation type="unfinished">武器設置包括可以選用的武器和彈藥數量。</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation type="unfinished">
            <numerusform>有%1個用戶端連接到這個房間。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation type="unfinished">
            <numerusform>有%1個隊伍加入這個房間。</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>請鍵入房間名</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>請從列表選中房間</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">清除</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>New</source>
        <translation>新模式</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">開啟隨機地雷</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>傷害的80%變成自身力量</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>分擔你的對手的疼痛</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>你的刺蝟不能移動，檢驗你射擊技巧的時候到了</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>隨機</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>秒鐘</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>保衛你的城堡，破壞對手的，努力吧！</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>隊伍開始在對手的地盤，努力！</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>地面無法破壞！</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>添加不可毀壞地邊界</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>低重力</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>鐳射瞄準輔助</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>每個刺蝟都有一個力場</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>隨機出場順序</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>國王不能死!!</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>在開局前手動放置刺猬</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>默認</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">新模式</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>快速遊戲 (對抗電腦，固定設置)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>多人遊戲 (熱坐對抗朋友或AI)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>訓練模式 (一系列訓練任務)。開發中</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demo (觀看記錄的Demo)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>讀取 (讀取之前保存的遊戲)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>踢</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>限制參與</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>限制團隊外掛程式</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>封鎖</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>跟隨</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Enable sound</source>
        <translation type="unfinished">開啟遊戲音效</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>遊戲全螢幕</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>顯示幀率 (FPS)</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>另一種傷害顯示方式</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>介面全螢幕</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation type="unfinished">開啟遊戲音樂</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>記錄名稱中包含具體時間日期</translation>
    </message>
    <message>
        <source>Check for updates at startup</source>
        <translation>啟動時檢查程式升級</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">降低顯示效果</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation type="unfinished">顯示武器提示訊息</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation type="unfinished">啟用菜單音效</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation type="unfinished">啟用菜單音樂</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>生成地圖...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>玩家</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Lv 級別</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mission</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">默認</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>成員</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>城堡模式</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>鍵位綁定</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>隊伍</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>音訊/視頻選項</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>玩家隊伍</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>網路遊戲</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">武器</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>遊戲修改</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>基本設置</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Net nick</source>
        <translation>網路遊戲昵稱</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>This program is distributed under the GNU General Public License</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>解析度</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS 上限</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>開發者:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>藝術:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>翻譯:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>特別感謝:</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>伺服器名:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>伺服器埠:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>主機:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>埠:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>武器</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>聲音:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>初始音量</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>傷害修改</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>回合時間</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>初始生命值</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>死亡模式倒計時</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>設置名稱：</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>箱子降落</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>遊戲設置</translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation>佈雷時間</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>地雷</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>無名</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>刺蝟大作戰 %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>伺服器連接丟失</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>武器</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">不能刪除默認武器設定</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>真的刪除這個武器設定嗎?</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">不能更改默認的武器設定</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>打不開資料檔案目錄:
%1
請檢查</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams</source>
        <translation type="unfinished">隊伍</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>無法創建路徑 %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished">匿稱</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation type="unfinished">請輸入您的匿稱</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Setup</source>
        <translation>設置</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>播放 demo</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>連接</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>出場！</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>開始服務端</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>讀取</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>指定</translation>
    </message>
    <message>
        <source>default</source>
        <translation>默認</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>準備好了</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation type="unfinished">隨機隊伍分配</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation type="unfinished">房間名</translation>
    </message>
    <message>
        <source>C</source>
        <translation type="unfinished">人數</translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished">隊伍</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation type="unfinished">創建者</translation>
    </message>
    <message>
        <source>Map</source>
        <translation type="unfinished">地圖</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation type="unfinished">規則</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="unfinished">武器</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation type="unfinished">武器設置</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation type="unfinished">幾率</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new</source>
        <translation type="unfinished">新</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>無法開始服務端: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>無法運行引擎: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>吸血鬼</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>因果報應</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>射術</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>城堡模式</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>團體行動</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>固實地面</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>添加邊界</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>低重力</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>鐳射瞄準</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>刀槍不入</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">佈置地雷</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation type="unfinished">隨機順序</translation>
    </message>
    <message>
        <source>King</source>
        <translation type="unfinished">國王模式</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation type="unfinished">手動放置</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>上</translation>
    </message>
    <message>
        <source>left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>down</source>
        <translation>下</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>攻擊</translation>
    </message>
    <message>
        <source>put</source>
        <translation>放</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>切換</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>定時1秒</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>定時2秒</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>定時3秒</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>定時4秒</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>定時5秒</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>奪取</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>尋找刺蝟</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>彈藥菜單</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>降低音量</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>提高音量</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>改變模式</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>練習瞄準</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>聊天</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>聊天記錄</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>刺蝟大作戰
信息</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation type="unfinished">放大</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation type="unfinished">縮小</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation type="unfinished">重置</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation type="unfinished">跳遠</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation type="unfinished">跳高</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation type="unfinished">slot 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation type="unfinished">基本控制</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation type="unfinished">武器控制</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation type="unfinished">鏡頭和遊標控制</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">其他</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation type="unfinished">移動、瞄準：</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation type="unfinished">越過障礙：</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation type="unfinished">開火、使用物品：</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation type="unfinished">選取武器、目的地：</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation type="unfinished">切換刺蝟（如果可用）：</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation type="unfinished">選取武器、物品：</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation type="unfinished">設置定時炸彈等武器時間：</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation type="unfinished">移動鏡頭到選中刺蝟：</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation type="unfinished">不用滑鼠移動遊標或鏡頭：</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation type="unfinished">調整鏡頭放大倍數：</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation type="unfinished">同隊友或全部參與者對話：</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation type="unfinished">暫停、繼續或離開遊戲：</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation type="unfinished">調整遊戲時音量：</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation type="unfinished">全屏模式：</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation type="unfinished">截圖：</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation type="unfinished">切換刺蝟標籤顯示方式：</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation type="unfinished">軸</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation type="unfinished">上</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation type="unfinished">下</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation type="unfinished">帽子</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation type="unfinished">左</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation type="unfinished">右</translation>
    </message>
    <message>
        <source>Button</source>
        <translation type="unfinished">按鍵</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="unfinished">鍵盤</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>滑鼠：左鍵</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>滑鼠：中鍵</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>滑鼠：右鍵</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>滑鼠滾輪：向上</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>滑鼠滾輪：向下</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>倒退鍵</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>製錶鍵</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停鍵</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>逸出鍵</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>空白鍵</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除鍵</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>小鍵盤0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>小鍵盤1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>小鍵盤2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>小鍵盤3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>小鍵盤4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>小鍵盤5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>小鍵盤6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>小鍵盤7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>小鍵盤8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>小鍵盤9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>小鍵盤.</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>小鍵盤/</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>小鍵盤*</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>小鍵盤-</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>小鍵盤+</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>回車鍵</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>等於</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>插入鍵</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home鍵</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End鍵</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>向上翻頁鍵</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>向下翻頁鍵</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>小鍵盤數位鎖</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>大小寫切換鍵</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll Lock鍵</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>右Shift鍵</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>左Shift鍵</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>右Ctrl鍵</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>左Ctrl鍵</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>右Alt鍵</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>左Alt鍵</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>右meta鍵</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>左meta鍵</translation>
    </message>
    <message>
        <source>A button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
